@@ -691,8 +691,8 @@ class ChartVisualizationWidget(Static):
     ]
     
     def __init__(self, chart_type="line", **kwargs):
-        super().__init__(**kwargs)
-        self.data = []
+        
+        self.data = kwargs.pop("data", [])
         self.fields = []
         self.chart_configured = False
         self.chart_type = chart_type
@@ -702,9 +702,11 @@ class ChartVisualizationWidget(Static):
             "bar": {"x_field": None, "y_fields": [], "group_field": None}
         }
         # 保留兼容性字段
-        self.x_field = None
-        self.y_field = None
-        self.group_field = None
+        self.x_field = kwargs.pop("x_field", None)
+        self.y_fields = kwargs.pop("y_fields", None) or []
+        self.y_field = kwargs.pop("y_field", None)
+        self.group_field = kwargs.pop("group_field", None)
+        super().__init__(**kwargs)
     
     def compose(self) -> ComposeResult:
         """构建图表可视化UI"""
@@ -718,9 +720,6 @@ class ChartVisualizationWidget(Static):
     def update_data(self, data: List[Dict]):
         """更新数据并检查字段配置"""
         self.data = data
-        
-
-        
         if not data:
             self.fields = []
             self._show_field_config()
