@@ -17,6 +17,7 @@ from ketacli.sdk.chart.chart_utils.spl_textarea import SPLTextArea, SearchReques
 from ketacli.sdk.base.search import search_spl
 from ketacli.sdk.chart.chart_utils.search_history import SearchHistoryManager
 from ketacli.sdk.chart.view_switcher import EnhancedSearchResultWidget
+from ketacli.sdk.ai.functions.search_functions import validate_spl_value_quotes
 
 
 def format_time_field(field_name, value):
@@ -141,6 +142,8 @@ class RealDataSource:
     def search_data(self, spl_query, start=None, end=None, limit=100):
         """使用真实的搜索API进行数据搜索"""
         try:
+            # 运行前进行 SPL 值引号校验（字段值必须用双引号）
+            validate_spl_value_quotes(spl_query)
             # 调用真实的搜索API
             result = search_spl(spl_query, start=start, end=end, limit=limit)
             
